@@ -146,6 +146,9 @@ pub(crate) type ValueMap = std::collections::BTreeMap<StaticKey, Value>;
 
 thread_local! {
     static INTERNAL_SERIALIZATION: AtomicBool = AtomicBool::new(false);
+
+    // This should be an AtomicU64 but sadly 32bit targets do not necessarily have
+    // AtomicU64 available.
     static LAST_VALUE_HANDLE: AtomicUsize = AtomicUsize::new(0);
     static VALUE_HANDLES: RefCell<BTreeMap<usize, Value>> = RefCell::new(BTreeMap::new());
 }
@@ -976,9 +979,9 @@ impl Value {
         let mut rv = self.clone();
         for part in path.split('.') {
             if let Ok(num) = part.parse::<usize>() {
-                rv = rv.get_item_by_index(num)?;
+                rv = ok!(rv.get_item_by_index(num));
             } else {
-                rv = rv.get_attr(part)?;
+                rv = ok!(rv.get_attr(part));
             }
         }
         Ok(rv)
@@ -1006,8 +1009,7 @@ impl Serialize for Value {
             ValueRepr::I64(i) => serializer.serialize_i64(i),
             ValueRepr::F64(f) => serializer.serialize_f64(f),
             ValueRepr::Char(c) => serializer.serialize_char(c),
-            ValueRepr::None => serializer.serialize_unit(),
-            ValueRepr::Undefined => serializer.serialize_unit(),
+            ValueRepr::None | ValueRepr::Undefined => serializer.serialize_unit(),
             ValueRepr::U128(u) => serializer.serialize_u128(u.0),
             ValueRepr::I128(i) => serializer.serialize_i128(i.0),
             ValueRepr::String(ref s, _) => serializer.serialize_str(s),
@@ -1165,6 +1167,8 @@ impl ValueIteratorState {
 
 #[test]
 fn test_dynamic_object_roundtrip() {
+    use std::sync::atomic::AtomicUsize;
+
     #[derive(Debug)]
     struct X(AtomicUsize);
 
